@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
+# Python 3.8.5 (default, Sep  4 2020, 07:30:14)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -34,7 +34,7 @@ import datetime as datetime_
 import decimal as decimal_
 try:
     from lxml import etree as etree_
-except ImportError:
+except ModuleNotFoundError:
     from xml.etree import ElementTree as etree_
 
 
@@ -113,11 +113,11 @@ def parsexmlstring_(instring, parser=None, **kwargs):
 
 try:
     from generatedsnamespaces import GenerateDSNamespaceDefs as GenerateDSNamespaceDefs_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceDefs_ = {}
 try:
     from generatedsnamespaces import GenerateDSNamespaceTypePrefixes as GenerateDSNamespaceTypePrefixes_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceTypePrefixes_ = {}
 
 #
@@ -128,7 +128,7 @@ except ImportError:
 #
 try:
     from generatedscollector import GdsCollector as GdsCollector_
-except ImportError:
+except ModuleNotFoundError:
 
     class GdsCollector_(object):
 
@@ -162,7 +162,7 @@ except ImportError:
 
 try:
     from enum import Enum
-except ImportError:
+except ModuleNotFoundError:
     Enum = object
 
 #
@@ -174,7 +174,7 @@ except ImportError:
 
 try:
     from generatedssuper import GeneratedsSuper
-except ImportError as exp:
+except ModuleNotFoundError as exp:
     
     class GeneratedsSuper(object):
         __hash__ = object.__hash__
@@ -1515,6 +1515,12 @@ if __name__ == '__main__':
 RenameMappings_ = {
 }
 
+#
+# Mapping of namespaces to types defined in them
+# and the file in which each is defined.
+# simpleTypes are marked "ST" and complexTypes "CT".
+NamespaceToDefMappings_ = {}
+
 __all__ = [
     "document1Type",
     "document2Type",
