@@ -38,7 +38,7 @@ import datetime as datetime_
 import decimal as decimal_
 ## try:
 ##     from lxml import etree as etree_
-## except ImportError:
+## except ModuleNotFoundError:
 ##     from xml.etree import ElementTree as etree_
 
 
@@ -117,11 +117,11 @@ else:
 
 try:
     from generatedsnamespaces import GenerateDSNamespaceDefs as GenerateDSNamespaceDefs_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceDefs_ = {}
 try:
     from generatedsnamespaces import GenerateDSNamespaceTypePrefixes as GenerateDSNamespaceTypePrefixes_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceTypePrefixes_ = {}
 
 #
@@ -132,7 +132,7 @@ except ImportError:
 #
 try:
     from generatedscollector import GdsCollector as GdsCollector_
-except ImportError:
+except ModuleNotFoundError:
 
     class GdsCollector_(object):
 
@@ -166,7 +166,7 @@ except ImportError:
 
 try:
     from enum import Enum
-except ImportError:
+except ModuleNotFoundError:
     Enum = object
 
 #
