@@ -37,7 +37,7 @@ import datetime as datetime_
 import decimal as decimal_
 try:
     from lxml import etree as etree_
-except ImportError:
+except ModuleNotFoundError:
     from xml.etree import ElementTree as etree_
 
 
@@ -116,11 +116,11 @@ def parsexmlstring_(instring, parser=None, **kwargs):
 
 try:
     from generatedsnamespaces import GenerateDSNamespaceDefs as GenerateDSNamespaceDefs_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceDefs_ = {}
 try:
     from generatedsnamespaces import GenerateDSNamespaceTypePrefixes as GenerateDSNamespaceTypePrefixes_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceTypePrefixes_ = {}
 
 #
@@ -131,7 +131,7 @@ except ImportError:
 #
 try:
     from generatedscollector import GdsCollector as GdsCollector_
-except ImportError:
+except ModuleNotFoundError:
 
     class GdsCollector_(object):
 
@@ -165,7 +165,7 @@ except ImportError:
 
 try:
     from enum import Enum
-except ImportError:
+except ModuleNotFoundError:
     Enum = object
 
 #
