@@ -33,7 +33,7 @@ import datetime as datetime_
 import decimal as decimal_
 try:
     from lxml import etree as etree_
-except ImportError:
+except ModuleNotFoundError:
     from xml.etree import ElementTree as etree_
 
 
@@ -112,11 +112,11 @@ def parsexmlstring_(instring, parser=None, **kwargs):
 
 try:
     from generatedsnamespaces import GenerateDSNamespaceDefs as GenerateDSNamespaceDefs_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceDefs_ = {}
 try:
     from generatedsnamespaces import GenerateDSNamespaceTypePrefixes as GenerateDSNamespaceTypePrefixes_
-except ImportError:
+except ModuleNotFoundError:
     GenerateDSNamespaceTypePrefixes_ = {}
 
 #
@@ -127,7 +127,7 @@ except ImportError:
 #
 try:
     from generatedscollector import GdsCollector as GdsCollector_
-except ImportError:
+except ModuleNotFoundError:
 
     class GdsCollector_(object):
 
@@ -161,7 +161,7 @@ except ImportError:
 
 try:
     from enum import Enum
-except ImportError:
+except ModuleNotFoundError:
     Enum = object
 
 #
@@ -173,7 +173,7 @@ except ImportError:
 
 try:
     from generatedssuper import GeneratedsSuper
-except ImportError as exp:
+except ModuleNotFoundError as exp:
     
     class GeneratedsSuper(object):
         __hash__ = object.__hash__
