@@ -74,6 +74,13 @@ supermod.PersonType.subclass = PersonTypeSub
 # end class PersonTypeSub
 
 
+class PersonIdType1Sub(supermod.PersonIdType1):
+    def __init__(self, valueOf_=None, **kwargs_):
+        super(PersonIdType1Sub, self).__init__(valueOf_,  **kwargs_)
+supermod.PersonIdType1.subclass = PersonIdType1Sub
+# end class PersonIdType1Sub
+
+
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
